# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference


from ._code import code
from ._string import string
from ._uri import uri

from .codeableconcept import CodeableConcept
from .period import Period

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Identifier']


# ------------------------------------------------------------------------------
# Identifier
# ------------------------------------------------------------------------------
class Identifier(Element):
    """
    An identifier - identifies some entity uniquely and unambiguously.
    Typically this is used for business identifiers.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Identifier'
    
    use = Property('use', code, '0', '1')
    type = Property('type', CodeableConcept, '0', '1')
    system = Property('system', uri, '0', '1')
    value = Property('value', string, '0', '1')
    period = Property('period', Period, '0', '1')
    assigner = Property('assigner', Reference("http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')
