# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._canonical import canonical
from ._code import code
from ._datetime import dateTime
from ._unsignedint import unsignedInt
from ._uri import uri

from .annotation import Annotation
from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .dosage import Dosage
from .duration import Duration
from .identifier import Identifier
from .period import Period
from .quantity import Quantity

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['MedicationRequest']

class DispenseRequest(BackboneElement):
    """Autogenerated class for implicit type."""
    initialFill = Property('initialFill', 'InitialFill', '0', '1')
    dispenseInterval = Property('dispenseInterval', 'Duration', '0', '1')
    validityPeriod = Property('validityPeriod', 'Period', '0', '1')
    numberOfRepeatsAllowed = Property('numberOfRepeatsAllowed', 'unsignedInt', '0', '1')
    quantity = Property('quantity', 'Quantity', '0', '1')
    expectedSupplyDuration = Property('expectedSupplyDuration', 'Duration', '0', '1')
    performer = Property('performer', Reference("http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')        

class InitialFill(BackboneElement):
    """Autogenerated class for implicit type."""
    quantity = Property('quantity', 'Quantity', '0', '1')
    duration = Property('duration', 'Duration', '0', '1')

class Substitution(BackboneElement):
    """Autogenerated class for implicit type."""
    allowed = Property('allowed', ['boolean', 'CodeableConcept'], '1', '1')
    reason = Property('reason', 'CodeableConcept', '0', '1')


# ------------------------------------------------------------------------------
# MedicationRequest
# ------------------------------------------------------------------------------
class MedicationRequest(DomainResource):
    """
    An order or request for both supply of the medication and the
    instructions for administration of the medication to a patient. The
    resource is called "MedicationRequest" rather than
    "MedicationPrescription" or "MedicationOrder" to generalize the use
    across inpatient and outpatient settings, including care plans, etc.,
    and to harmonize with workflow patterns.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/MedicationRequest'
    
    identifier = Property('identifier', Identifier, '0', '*')
    status = Property('status', code, '1', '1')
    statusReason = Property('statusReason', CodeableConcept, '0', '1')
    intent = Property('intent', code, '1', '1')
    category = Property('category', CodeableConcept, '0', '*')
    priority = Property('priority', code, '0', '1')
    doNotPerform = Property('doNotPerform', boolean, '0', '1')
    reported = Property('reported', ['boolean', 'Reference("http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/RelatedPerson", "http://hl7.org/fhir/StructureDefinition/Organization")'], '0', '1')
    medication = Property('medication', ['CodeableConcept', 'Reference("http://hl7.org/fhir/StructureDefinition/Medication")'], '1', '1')
    subject = Property('subject', Reference("http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/Group"), '1', '1')
    encounter = Property('encounter', Reference("http://hl7.org/fhir/StructureDefinition/Encounter"), '0', '1')
    supportingInformation = Property('supportingInformation', Reference("http://hl7.org/fhir/StructureDefinition/Resource"), '0', '*')
    authoredOn = Property('authoredOn', dateTime, '0', '1')
    requester = Property('requester', Reference("http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/Organization", "http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/RelatedPerson", "http://hl7.org/fhir/StructureDefinition/Device"), '0', '1')
    performer = Property('performer', Reference("http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/Organization", "http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/Device", "http://hl7.org/fhir/StructureDefinition/RelatedPerson", "http://hl7.org/fhir/StructureDefinition/CareTeam"), '0', '1')
    performerType = Property('performerType', CodeableConcept, '0', '1')
    recorder = Property('recorder', Reference("http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole"), '0', '1')
    reasonCode = Property('reasonCode', CodeableConcept, '0', '*')
    reasonReference = Property('reasonReference', Reference("http://hl7.org/fhir/StructureDefinition/Condition", "http://hl7.org/fhir/StructureDefinition/Observation"), '0', '*')
    instantiatesCanonical = Property('instantiatesCanonical', canonical, '0', '*')
    instantiatesUri = Property('instantiatesUri', uri, '0', '*')
    basedOn = Property('basedOn', Reference("http://hl7.org/fhir/StructureDefinition/CarePlan", "http://hl7.org/fhir/StructureDefinition/MedicationRequest", "http://hl7.org/fhir/StructureDefinition/ServiceRequest", "http://hl7.org/fhir/StructureDefinition/ImmunizationRecommendation"), '0', '*')
    groupIdentifier = Property('groupIdentifier', Identifier, '0', '1')
    courseOfTherapyType = Property('courseOfTherapyType', CodeableConcept, '0', '1')
    insurance = Property('insurance', Reference("http://hl7.org/fhir/StructureDefinition/Coverage", "http://hl7.org/fhir/StructureDefinition/ClaimResponse"), '0', '*')
    note = Property('note', Annotation, '0', '*')
    dosageInstruction = Property('dosageInstruction', Dosage, '0', '*')
    dispenseRequest = Property('dispenseRequest', DispenseRequest, '0', '1')
    substitution = Property('substitution', Substitution, '0', '1')
    priorPrescription = Property('priorPrescription', Reference("http://hl7.org/fhir/StructureDefinition/MedicationRequest"), '0', '1')
    detectedIssue = Property('detectedIssue', Reference("http://hl7.org/fhir/StructureDefinition/DetectedIssue"), '0', '*')
    eventHistory = Property('eventHistory', Reference("http://hl7.org/fhir/StructureDefinition/Provenance"), '0', '*')
