# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference


from ._code import code
from ._decimal import decimal
from ._string import string
from ._uri import uri


__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Quantity']


# ------------------------------------------------------------------------------
# Quantity
# ------------------------------------------------------------------------------
class Quantity(Element):
    """
    A measured amount (or an amount that can potentially be measured).
    Note that measured amounts include amounts that are not precisely
    quantified, including amounts involving arbitrary units and floating
    currencies.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Quantity'
    
    value = Property('value', decimal, '0', '1')
    comparator = Property('comparator', code, '0', '1')
    unit = Property('unit', string, '0', '1')
    system = Property('system', uri, '0', '1')
    code = Property('code', code, '0', '1')
