# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._canonical import canonical
from ._code import code
from ._date import date
from ._datetime import dateTime
from ._decimal import decimal
from ._integer import integer
from ._string import string
from ._time import time
from ._uri import uri

from .attachment import Attachment
from .backboneelement import BackboneElement
from .coding import Coding
from .identifier import Identifier
from .quantity import Quantity

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['QuestionnaireResponse']

class Item(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '1', '1')
    definition = Property('definition', 'uri', '0', '1')
    text = Property('text', 'string', '0', '1')
    answer = Property('answer', 'Answer', '0', '*')
    item = Property('item', 'Item', '0', '*')

class Answer(BackboneElement):
    """Autogenerated class for implicit type."""
    value = Property('value', ['boolean', 'decimal', 'integer', 'date', 'dateTime', 'time', 'string', 'uri', 'Attachment', 'Coding', 'Quantity', 'Reference("http://hl7.org/fhir/StructureDefinition/Resource")'], '0', '1')
    item = Property('item', 'Item', '0', '*')


# ------------------------------------------------------------------------------
# QuestionnaireResponse
# ------------------------------------------------------------------------------
class QuestionnaireResponse(DomainResource):
    """
    A structured set of questions and their answers. The questions are
    ordered and grouped into coherent subsets, corresponding to the
    structure of the grouping of the questionnaire being responded to.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/QuestionnaireResponse'
    
    identifier = Property('identifier', Identifier, '0', '1')
    basedOn = Property('basedOn', Reference("http://hl7.org/fhir/StructureDefinition/CarePlan", "http://hl7.org/fhir/StructureDefinition/ServiceRequest"), '0', '*')
    partOf = Property('partOf', Reference("http://hl7.org/fhir/StructureDefinition/Observation", "http://hl7.org/fhir/StructureDefinition/Procedure"), '0', '*')
    questionnaire = Property('questionnaire', canonical, '0', '1')
    status = Property('status', code, '1', '1')
    subject = Property('subject', Reference("http://hl7.org/fhir/StructureDefinition/Resource"), '0', '1')
    encounter = Property('encounter', Reference("http://hl7.org/fhir/StructureDefinition/Encounter"), '0', '1')
    authored = Property('authored', dateTime, '0', '1')
    author = Property('author', Reference("http://hl7.org/fhir/StructureDefinition/Device", "http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/RelatedPerson", "http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')
    source = Property('source', Reference("http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/RelatedPerson"), '0', '1')
    item = Property('item', Item, '0', '*')
