# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference



from .codeableconcept import CodeableConcept
from .coding import Coding
from .quantity import Quantity
from .range import Range

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['UsageContext']


# ------------------------------------------------------------------------------
# UsageContext
# ------------------------------------------------------------------------------
class UsageContext(Element):
    """
    Specifies clinical/business/etc. metadata that can be used to
    retrieve, index and/or categorize an artifact. This metadata can
    either be specific to the applicable population (e.g., age category,
    DRG) or the specific context of care (e.g., venue, care setting,
    provider of care).
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/UsageContext'
    
    code = Property('code', Coding, '1', '1')
    value = Property('value', ['CodeableConcept', 'Quantity', 'Range', 'Reference("http://hl7.org/fhir/StructureDefinition/PlanDefinition", "http://hl7.org/fhir/StructureDefinition/ResearchStudy", "http://hl7.org/fhir/StructureDefinition/InsurancePlan", "http://hl7.org/fhir/StructureDefinition/HealthcareService", "http://hl7.org/fhir/StructureDefinition/Group", "http://hl7.org/fhir/StructureDefinition/Location", "http://hl7.org/fhir/StructureDefinition/Organization")'], '1', '1')
