# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._code import code
from ._datetime import dateTime
from ._instant import instant
from ._string import string
from ._time import time

from .attachment import Attachment
from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .identifier import Identifier
from .period import Period
from .quantity import Quantity
from .range import Range
from .ratio import Ratio
from .sampleddata import SampledData

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Observation']

class ReferenceRange(BackboneElement):
    """Autogenerated class for implicit type."""
    low = Property('low', 'Quantity', '0', '1')
    high = Property('high', 'Quantity', '0', '1')
    meaning = Property('meaning', 'CodeableConcept', '0', '1')
    age = Property('age', 'Range', '0', '1')
    text = Property('text', 'string', '0', '1')

class Related(BackboneElement):
    """Autogenerated class for implicit type."""
    type = Property('type', 'code', '0', '1')
    target = Property('target', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Observation")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/QuestionnaireResponse")'], '1', '1')

class Component(BackboneElement):
    """Autogenerated class for implicit type."""
    code = Property('code', 'CodeableConcept', '1', '1')
    value = Property('value', ['Quantity', 'CodeableConcept', 'string', 'Range', 'Ratio', 'SampledData', 'Attachment', 'time', 'dateTime', 'Period'], '0', '1')
    dataAbsentReason = Property('dataAbsentReason', 'CodeableConcept', '0', '1')
    referenceRange = Property('referenceRange', 'ReferenceRange', '0', '*')


# ------------------------------------------------------------------------------
# Observation
# ------------------------------------------------------------------------------
class Observation(DomainResource):
    """
    Measurements and simple assertions made about a patient, device or
    other subject.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Observation'
    
    identifier = Property('identifier', Identifier, '0', '*')
    status = Property('status', code, '1', '1')
    category = Property('category', CodeableConcept, '0', '1')
    code = Property('code', CodeableConcept, '1', '1')
    subject = Property('subject', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Group")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Device")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Location")'], '0', '1')
    encounter = Property('encounter', Reference(reference="http://hl7.org/fhir/StructureDefinition/Encounter"), '0', '1')
    effective = Property('effective', ['dateTime', 'Period'], '0', '1')
    issued = Property('issued', instant, '0', '1')
    performer = Property('performer', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Practitioner")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Organization")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/RelatedPerson")'], '0', '*')
    value = Property('value', ['Quantity', 'CodeableConcept', 'string', 'Range', 'Ratio', 'SampledData', 'Attachment', 'time', 'dateTime', 'Period'], '0', '1')
    dataAbsentReason = Property('dataAbsentReason', CodeableConcept, '0', '1')
    interpretation = Property('interpretation', CodeableConcept, '0', '1')
    comments = Property('comments', string, '0', '1')
    bodySite = Property('bodySite', CodeableConcept, '0', '1')
    method = Property('method', CodeableConcept, '0', '1')
    specimen = Property('specimen', Reference(reference="http://hl7.org/fhir/StructureDefinition/Specimen"), '0', '1')
    device = Property('device', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Device")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/DeviceMetric")'], '0', '1')
    referenceRange = Property('referenceRange', ReferenceRange, '0', '*')
    related = Property('related', Related, '0', '*')
    component = Property('component', Component, '0', '*')
