# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._code import code
from ._date import date
from ._datetime import dateTime
from ._integer import integer

from .address import Address
from .attachment import Attachment
from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .contactpoint import ContactPoint
from .humanname import HumanName
from .identifier import Identifier
from .period import Period

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Patient']

class Contact(BackboneElement):
    """Autogenerated class for implicit type."""
    relationship = Property('relationship', 'CodeableConcept', '0', '*')
    name = Property('name', 'HumanName', '0', '1')
    telecom = Property('telecom', 'ContactPoint', '0', '*')
    address = Property('address', 'Address', '0', '1')
    gender = Property('gender', 'code', '0', '1')
    organization = Property('organization', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Organization")', '0', '1')
    period = Property('period', 'Period', '0', '1')

class Animal(BackboneElement):
    """Autogenerated class for implicit type."""
    species = Property('species', 'CodeableConcept', '1', '1')
    breed = Property('breed', 'CodeableConcept', '0', '1')
    genderStatus = Property('genderStatus', 'CodeableConcept', '0', '1')

class Communication(BackboneElement):
    """Autogenerated class for implicit type."""
    language = Property('language', 'CodeableConcept', '1', '1')
    preferred = Property('preferred', 'boolean', '0', '1')

class Link(BackboneElement):
    """Autogenerated class for implicit type."""
    other = Property('other', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', '1', '1')
    type = Property('type', 'code', '1', '1')


# ------------------------------------------------------------------------------
# Patient
# ------------------------------------------------------------------------------
class Patient(DomainResource):
    """
    Demographics and other administrative information about an individual
    or animal receiving care or other health-related services.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Patient'
    
    identifier = Property('identifier', Identifier, '0', '*')
    active = Property('active', boolean, '0', '1')
    name = Property('name', HumanName, '0', '*')
    telecom = Property('telecom', ContactPoint, '0', '*')
    gender = Property('gender', code, '0', '1')
    birthDate = Property('birthDate', date, '0', '1')
    deceased = Property('deceased', ['boolean', 'dateTime'], '0', '1')
    address = Property('address', Address, '0', '*')
    maritalStatus = Property('maritalStatus', CodeableConcept, '0', '1')
    multipleBirth = Property('multipleBirth', ['boolean', 'integer'], '0', '1')
    photo = Property('photo', Attachment, '0', '*')
    contact = Property('contact', Contact, '0', '*')
    animal = Property('animal', Animal, '0', '1')
    communication = Property('communication', Communication, '0', '*')
    careProvider = Property('careProvider', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Organization")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Practitioner")'], '0', '*')
    managingOrganization = Property('managingOrganization', Reference(reference="http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')
    link = Property('link', Link, '0', '*')
