# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._code import code
from ._datetime import dateTime
from ._string import string

from .backboneelement import BackboneElement
from .coding import Coding
from .contactpoint import ContactPoint
from .identifier import Identifier

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Questionnaire']

class Group(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '0', '1')
    title = Property('title', 'string', '0', '1')
    concept = Property('concept', 'Coding', '0', '*')
    text = Property('text', 'string', '0', '1')
    required = Property('required', 'boolean', '0', '1')
    repeats = Property('repeats', 'boolean', '0', '1')
    group = Property('group', 'Group', '0', '*')
    question = Property('question', 'Question', '0', '*')

class Question(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '0', '1')
    concept = Property('concept', 'Coding', '0', '*')
    text = Property('text', 'string', '0', '1')
    type = Property('type', 'code', '0', '1')
    required = Property('required', 'boolean', '0', '1')
    repeats = Property('repeats', 'boolean', '0', '1')
    options = Property('options', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/ValueSet")', '0', '1')
    option = Property('option', 'Coding', '0', '*')
    group = Property('group', 'Group', '0', '*')


# ------------------------------------------------------------------------------
# Questionnaire
# ------------------------------------------------------------------------------
class Questionnaire(DomainResource):
    """
    A structured set of questions intended to guide the collection of
    answers. The questions are ordered and grouped into coherent subsets,
    corresponding to the structure of the grouping of the underlying
    questions.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Questionnaire'
    
    identifier = Property('identifier', Identifier, '0', '*')
    version = Property('version', string, '0', '1')
    status = Property('status', code, '1', '1')
    date = Property('date', dateTime, '0', '1')
    publisher = Property('publisher', string, '0', '1')
    telecom = Property('telecom', ContactPoint, '0', '*')
    subjectType = Property('subjectType', code, '0', '*')
    group = Property('group', Group, '1', '1')
