# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._code import code
from ._date import date
from ._datetime import dateTime
from ._decimal import decimal
from ._instant import instant
from ._integer import integer
from ._string import string
from ._time import time
from ._uri import uri

from .attachment import Attachment
from .backboneelement import BackboneElement
from .coding import Coding
from .identifier import Identifier
from .quantity import Quantity

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['QuestionnaireResponse']

class Group(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '0', '1')
    title = Property('title', 'string', '0', '1')
    text = Property('text', 'string', '0', '1')
    subject = Property('subject', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Resource")', '0', '1')
    group = Property('group', 'Group', '0', '*')
    question = Property('question', 'Question', '0', '*')

class Question(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '0', '1')
    text = Property('text', 'string', '0', '1')
    answer = Property('answer', 'Answer', '0', '*')

class Answer(BackboneElement):
    """Autogenerated class for implicit type."""
    value = Property('value', ['boolean', 'decimal', 'integer', 'date', 'dateTime', 'instant', 'time', 'string', 'uri', 'Attachment', 'Coding', 'Quantity', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Resource")'], '0', '1')
    group = Property('group', 'Group', '0', '*')


# ------------------------------------------------------------------------------
# QuestionnaireResponse
# ------------------------------------------------------------------------------
class QuestionnaireResponse(DomainResource):
    """
    A structured set of questions and their answers. The questions are
    ordered and grouped into coherent subsets, corresponding to the
    structure of the grouping of the underlying questions.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/QuestionnaireResponse'
    
    identifier = Property('identifier', Identifier, '0', '1')
    questionnaire = Property('questionnaire', Reference(reference="http://hl7.org/fhir/StructureDefinition/Questionnaire"), '0', '1')
    status = Property('status', code, '1', '1')
    subject = Property('subject', Reference(reference="http://hl7.org/fhir/StructureDefinition/Resource"), '0', '1')
    author = Property('author', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Device")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Practitioner")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/RelatedPerson")'], '0', '1')
    authored = Property('authored', dateTime, '0', '1')
    source = Property('source', ['Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Practitioner")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/RelatedPerson")'], '0', '1')
    encounter = Property('encounter', Reference(reference="http://hl7.org/fhir/StructureDefinition/Encounter"), '0', '1')
    group = Property('group', Group, '0', '1')
