# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference


from ._base64binary import base64Binary
from ._code import code
from ._instant import instant
from ._uri import uri

from .coding import Coding

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Signature']


# ------------------------------------------------------------------------------
# Signature
# ------------------------------------------------------------------------------
class Signature(Element):
    """
    A digital signature along with supporting context. The signature may
    be electronic/cryptographic in nature, or a graphical image
    representing a hand-written signature, or a signature process.
    Different Signature approaches have different utilities.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Signature'
    
    type = Property('type', Coding, '1', '*')
    when = Property('when', instant, '1', '1')
    who = Property('who', ['uri', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Practitioner")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/RelatedPerson")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Patient")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Device")', 'Reference(reference="http://hl7.org/fhir/StructureDefinition/Organization")'], '1', '1')
    contentType = Property('contentType', code, '1', '1')
    blob = Property('blob', base64Binary, '1', '1')
