# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._code import code
from ._positiveint import positiveInt

from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .coding import Coding
from .duration import Duration
from .identifier import Identifier
from .period import Period

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Encounter']

class StatusHistory(BackboneElement):
    """Autogenerated class for implicit type."""
    status = Property('status', 'code', '1', '1')
    period = Property('period', 'Period', '1', '1')

class ClassHistory(BackboneElement):
    """Autogenerated class for implicit type."""
    class_ = Property('class_', 'Coding', '1', '1')
    period = Property('period', 'Period', '1', '1')

class Participant(BackboneElement):
    """Autogenerated class for implicit type."""
    type = Property('type', 'CodeableConcept', '0', '*')
    period = Property('period', 'Period', '0', '1')
    individual = Property('individual', Reference("http://hl7.org/fhir/StructureDefinition/Practitioner", "http://hl7.org/fhir/StructureDefinition/PractitionerRole", "http://hl7.org/fhir/StructureDefinition/RelatedPerson"), '0', '1')        

class Diagnosis(BackboneElement):
    """Autogenerated class for implicit type."""
    condition = Property('condition', Reference("http://hl7.org/fhir/StructureDefinition/Condition", "http://hl7.org/fhir/StructureDefinition/Procedure"), '1', '1')        
    use = Property('use', 'CodeableConcept', '0', '1')
    rank = Property('rank', 'positiveInt', '0', '1')

class Hospitalization(BackboneElement):
    """Autogenerated class for implicit type."""
    preAdmissionIdentifier = Property('preAdmissionIdentifier', 'Identifier', '0', '1')
    origin = Property('origin', Reference("http://hl7.org/fhir/StructureDefinition/Location", "http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')        
    admitSource = Property('admitSource', 'CodeableConcept', '0', '1')
    reAdmission = Property('reAdmission', 'CodeableConcept', '0', '1')
    dietPreference = Property('dietPreference', 'CodeableConcept', '0', '*')
    specialCourtesy = Property('specialCourtesy', 'CodeableConcept', '0', '*')
    specialArrangement = Property('specialArrangement', 'CodeableConcept', '0', '*')
    destination = Property('destination', Reference("http://hl7.org/fhir/StructureDefinition/Location", "http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')        
    dischargeDisposition = Property('dischargeDisposition', 'CodeableConcept', '0', '1')

class Location(BackboneElement):
    """Autogenerated class for implicit type."""
    location = Property('location', Reference("http://hl7.org/fhir/StructureDefinition/Location"), '1', '1')        
    status = Property('status', 'code', '0', '1')
    physicalType = Property('physicalType', 'CodeableConcept', '0', '1')
    period = Property('period', 'Period', '0', '1')


# ------------------------------------------------------------------------------
# Encounter
# ------------------------------------------------------------------------------
class Encounter(DomainResource):
    """
    An interaction between a patient and healthcare provider(s) for the
    purpose of providing healthcare service(s) or assessing the health
    status of a patient.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Encounter'
    
    identifier = Property('identifier', Identifier, '0', '*')
    status = Property('status', code, '1', '1')
    statusHistory = Property('statusHistory', StatusHistory, '0', '*')
    class_ = Property('class_', Coding, '1', '1')
    classHistory = Property('classHistory', ClassHistory, '0', '*')
    type = Property('type', CodeableConcept, '0', '*')
    serviceType = Property('serviceType', CodeableConcept, '0', '1')
    priority = Property('priority', CodeableConcept, '0', '1')
    subject = Property('subject', Reference("http://hl7.org/fhir/StructureDefinition/Patient", "http://hl7.org/fhir/StructureDefinition/Group"), '0', '1')
    episodeOfCare = Property('episodeOfCare', Reference("http://hl7.org/fhir/StructureDefinition/EpisodeOfCare"), '0', '*')
    basedOn = Property('basedOn', Reference("http://hl7.org/fhir/StructureDefinition/ServiceRequest"), '0', '*')
    participant = Property('participant', Participant, '0', '*')
    appointment = Property('appointment', Reference("http://hl7.org/fhir/StructureDefinition/Appointment"), '0', '*')
    period = Property('period', Period, '0', '1')
    length = Property('length', Duration, '0', '1')
    reasonCode = Property('reasonCode', CodeableConcept, '0', '*')
    reasonReference = Property('reasonReference', Reference("http://hl7.org/fhir/StructureDefinition/Condition", "http://hl7.org/fhir/StructureDefinition/Procedure", "http://hl7.org/fhir/StructureDefinition/Observation", "http://hl7.org/fhir/StructureDefinition/ImmunizationRecommendation"), '0', '*')
    diagnosis = Property('diagnosis', Diagnosis, '0', '*')
    account = Property('account', Reference("http://hl7.org/fhir/StructureDefinition/Account"), '0', '*')
    hospitalization = Property('hospitalization', Hospitalization, '0', '1')
    location = Property('location', Location, '0', '*')
    serviceProvider = Property('serviceProvider', Reference("http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')
    partOf = Property('partOf', Reference("http://hl7.org/fhir/StructureDefinition/Encounter"), '0', '1')
