# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._code import code
from ._datetime import dateTime
from ._string import string

from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .identifier import Identifier
from .ratio import Ratio

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Medication']

class Ingredient(BackboneElement):
    """Autogenerated class for implicit type."""
    item = Property('item', ['CodeableConcept', 'Reference("http://hl7.org/fhir/StructureDefinition/Substance", "http://hl7.org/fhir/StructureDefinition/Medication")'], '1', '1')
    isActive = Property('isActive', 'boolean', '0', '1')
    strength = Property('strength', 'Ratio', '0', '1')

class Batch(BackboneElement):
    """Autogenerated class for implicit type."""
    lotNumber = Property('lotNumber', 'string', '0', '1')
    expirationDate = Property('expirationDate', 'dateTime', '0', '1')


# ------------------------------------------------------------------------------
# Medication
# ------------------------------------------------------------------------------
class Medication(DomainResource):
    """
    This resource is primarily used for the identification and definition
    of a medication for the purposes of prescribing, dispensing, and
    administering a medication as well as for making statements about
    medication use.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Medication'
    
    identifier = Property('identifier', Identifier, '0', '*')
    code = Property('code', CodeableConcept, '0', '1')
    status = Property('status', code, '0', '1')
    manufacturer = Property('manufacturer', Reference("http://hl7.org/fhir/StructureDefinition/Organization"), '0', '1')
    form = Property('form', CodeableConcept, '0', '1')
    amount = Property('amount', Ratio, '0', '1')
    ingredient = Property('ingredient', Ingredient, '0', '*')
    batch = Property('batch', Batch, '0', '1')
