# -*- coding: utf-8 -*-
from __future__ import print_function
import datetime as dt
import logging

from . import Property
from . import FHIRBase, Element, Extension, Reference

from .backboneelement import BackboneElement
from .domainresource import DomainResource

from ._boolean import boolean
from ._canonical import canonical
from ._code import code
from ._date import date
from ._datetime import dateTime
from ._decimal import decimal
from ._integer import integer
from ._markdown import markdown
from ._string import string
from ._time import time
from ._uri import uri

from .attachment import Attachment
from .backboneelement import BackboneElement
from .codeableconcept import CodeableConcept
from .coding import Coding
from .contactdetail import ContactDetail
from .identifier import Identifier
from .period import Period
from .quantity import Quantity
from .usagecontext import UsageContext

__author__ = "Melle Sieswerda"
__copyright__  = "Copyright 2017, Melle Sieswerda"
__license__ = "GPL"
__version__ = "0.8"

__all__ = ['Questionnaire']

class Item(BackboneElement):
    """Autogenerated class for implicit type."""
    linkId = Property('linkId', 'string', '1', '1')
    definition = Property('definition', 'uri', '0', '1')
    code = Property('code', 'Coding', '0', '*')
    prefix = Property('prefix', 'string', '0', '1')
    text = Property('text', 'string', '0', '1')
    type = Property('type', 'code', '1', '1')
    enableWhen = Property('enableWhen', 'EnableWhen', '0', '*')
    enableBehavior = Property('enableBehavior', 'code', '0', '1')
    required = Property('required', 'boolean', '0', '1')
    repeats = Property('repeats', 'boolean', '0', '1')
    readOnly = Property('readOnly', 'boolean', '0', '1')
    maxLength = Property('maxLength', 'integer', '0', '1')
    answerValueSet = Property('answerValueSet', 'canonical', '0', '1')
    answerOption = Property('answerOption', 'AnswerOption', '0', '*')
    initial = Property('initial', 'Initial', '0', '*')
    item = Property('item', 'Item', '0', '*')

class EnableWhen(BackboneElement):
    """Autogenerated class for implicit type."""
    question = Property('question', 'string', '1', '1')
    operator = Property('operator', 'code', '1', '1')
    answer = Property('answer', ['boolean', 'decimal', 'integer', 'date', 'dateTime', 'time', 'string', 'Coding', 'Quantity', 'Reference("http://hl7.org/fhir/StructureDefinition/Resource")'], '1', '1')

class AnswerOption(BackboneElement):
    """Autogenerated class for implicit type."""
    value = Property('value', ['integer', 'date', 'time', 'string', 'Coding', 'Reference("http://hl7.org/fhir/StructureDefinition/Resource")'], '1', '1')
    initialSelected = Property('initialSelected', 'boolean', '0', '1')

class Initial(BackboneElement):
    """Autogenerated class for implicit type."""
    value = Property('value', ['boolean', 'decimal', 'integer', 'date', 'dateTime', 'time', 'string', 'uri', 'Attachment', 'Coding', 'Quantity', 'Reference("http://hl7.org/fhir/StructureDefinition/Resource")'], '1', '1')


# ------------------------------------------------------------------------------
# Questionnaire
# ------------------------------------------------------------------------------
class Questionnaire(DomainResource):
    """
    A structured set of questions intended to guide the collection of
    answers from end-users. Questionnaires provide detailed control over
    order, presentation, phraseology and grouping to allow coherent,
    consistent data collection.
    
    Autogenerated class.
    """
    _url = 'http://hl7.org/fhir/StructureDefinition/Questionnaire'
    
    url = Property('url', uri, '0', '1')
    identifier = Property('identifier', Identifier, '0', '*')
    version = Property('version', string, '0', '1')
    name = Property('name', string, '0', '1')
    title = Property('title', string, '0', '1')
    derivedFrom = Property('derivedFrom', canonical, '0', '*')
    status = Property('status', code, '1', '1')
    experimental = Property('experimental', boolean, '0', '1')
    subjectType = Property('subjectType', code, '0', '*')
    date = Property('date', dateTime, '0', '1')
    publisher = Property('publisher', string, '0', '1')
    contact = Property('contact', ContactDetail, '0', '*')
    description = Property('description', markdown, '0', '1')
    useContext = Property('useContext', UsageContext, '0', '*')
    jurisdiction = Property('jurisdiction', CodeableConcept, '0', '*')
    purpose = Property('purpose', markdown, '0', '1')
    copyright = Property('copyright', markdown, '0', '1')
    approvalDate = Property('approvalDate', date, '0', '1')
    lastReviewDate = Property('lastReviewDate', date, '0', '1')
    effectivePeriod = Property('effectivePeriod', Period, '0', '1')
    code = Property('code', Coding, '0', '*')
    item = Property('item', Item, '0', '*')
